@@ -1,6 +1,8 @@
 /*
   context_vanilla.cpp - wraps a gpgme key context, gpgme (vanilla)-specific functions
   Copyright (C) 2007 Klarälvdalens Datakonsult AB
+  2016 Bundesamt für Sicherheit in der Informationstechnik
+  Software engineering by Intevation GmbH
 
   This file is part of GPGME++.
 
@@ -28,10 +30,10 @@
 
 GIOChannel *GpgME::getGIOChannel(int)
 {
-    return 0;
+    return nullptr;
 }
 
 QIODevice *GpgME::getQIODevice(int)
 {
-    return 0;
+    return nullptr;
 }
